==> react-base-starter-project-0.1.1.tgz: package/templates/structure/electron/main.js <==
/**
 * File: main.js | Package: React Base Starter Project
 * 
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree
 * 
 * CapitalMental && BackLogics Technologies
 * Copyright 2014-present. | All rights reserved.
 */

const {
    app,
    BrowserWindow
} = require('electron')
const path = require('path')
const url  = require('url')

const confPathRelative = path.relative(__dirname, path.resolve(process.cwd(), "rbc.config.js"));
const conf             = require(confPathRelative)(true, true);
const public           = path.relative(__dirname, conf.paths.dest);

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
let win


function createWindow() {
    // Create the browser window.
    win = new BrowserWindow({
        width : 1150,
        height: 600,
        //transparent: true,
        //frame: true
    })

    global.publicPathRel = public;

    // and load the index.html of the app.
    win.loadURL(url.format({
        pathname: path.join(__dirname, 'index.html'),
        protocol: 'file:',
        slashes : true
    }))

    // Open the DevTools.
    win.webContents.openDevTools()

    // Emitted when the window is closed.
    win.on('closed', () => {
        // Dereference the window object, usually you would store windows
        // in an array if your app supports multi windows, this is the time
        // when you should delete the corresponding element.
        win = null
    })
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on('ready', createWindow)

// Quit when all windows are closed.
app.on('window-all-closed', () => {
    // On macOS it is common for applications and their menu bar
    // to stay active until the user quits explicitly with Cmd + Q
    if (process.platform !== 'darwin') {
        app.quit()
    }
})

app.on('activate', () => {
    // On macOS it's common to re-create a window in the app when the
    // dock icon is clicked and there are no other windows open.
    if (win === null) {
        createWindow()
    }
})

==> react-base-starter-project-0.1.2.tgz: package/templates/structure/electron/main.js <==
/**
 * File: main.js | Package: React Base Starter Project
 * 
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree
 * 
 * CapitalMental && BackLogics Technologies
 * Copyright 2014-present. | All rights reserved.
 */

const { app, BrowserWindow} = require('electron')
const path = require('path')
const url  = require('url')

const confPathRelative = path.relative(__dirname, path.resolve(process.cwd(), "rbc.config.js"));
const conf             = require(confPathRelative)(true, true);
const public           = path.relative(__dirname, conf.paths.dest);

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
let win

function createWindow() {
    // Create the browser window.
    win = new BrowserWindow({
        width : 1150,
        height: 600,
        preload: path.join(__dirname, 'preload.js'),
        nodeIntegration: false,
        //transparent: true,
        //frame: true
    })

    global.publicPathRel = public;

    // and load the index.html of the app.
   win.loadURL(url.format({
        // pathname: path.join(__dirname, 'index.html'),
        pathname: path.join(__dirname, 'index.html'),
        protocol: 'file:',
        slashes : true
    }));
    //win.loadFile(path.resolve(__dirname,"../public","index.html"));

    // Open the DevTools.
    win.webContents.openDevTools()

    // Emitted when the window is closed.
    win.on('closed', () => {
        // Dereference the window object, usually you would store windows
        // in an array if your app supports multi windows, this is the time
        // when you should delete the corresponding element.
        win = null
    })
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on('ready', createWindow)

// Quit when all windows are closed.
app.on('window-all-closed', () => {
    // On macOS it is common for applications and their menu bar
    // to stay active until the user quits explicitly with Cmd + Q
    if (process.platform !== 'darwin') {
        app.quit()
    }
})

app.on('activate', () => {
    // On macOS it's common to re-create a window in the app when the
    // dock icon is clicked and there are no other windows open.
    if (win === null) {
        createWindow()
    }
})
